==> sirikata-0.0.4-mac.tar.gz: sirikata_mac/include/sirikata/mesh/MeshSimplifier.hpp <==
/*  Sirikata
 *  MeshSimplifier.hpp
 *
 *  Copyright (c) 2010, Tahir Azim.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sirikata/mesh/Platform.hpp>
#include <sirikata/core/util/UUID.hpp>

#include <sirikata/core/transfer/TransferData.hpp>
#include <sirikata/core/transfer/RemoteFileMetadata.hpp>
#include <sirikata/core/transfer/TransferPool.hpp>
#include <sirikata/core/transfer/TransferMediator.hpp>

#include <sirikata/mesh/Meshdata.hpp>

namespace Sirikata {
namespace Mesh {

class SIRIKATA_MESH_EXPORT MeshSimplifier {
private:

  double invert(Matrix4x4f& inv, const Matrix4x4f& orig);

  typedef struct QSlimStruct {
    float mCost;
    int mGeomIdx, mIdx1, mIdx2;


    Vector3f mReplacementVector;

    QSlimStruct() {
      mCost = 1e-15;
    }

    QSlimStruct(float cost, int i, int idx1, int idx2, Vector3f v) {
      mCost = cost;
      mGeomIdx = i;
      mIdx1 = idx1;
      mIdx2 = idx2;
      mReplacementVector = v;
    }

    bool operator < (const QSlimStruct& qs) const {
      return mCost > qs.mCost;
    }

  } QSlimStruct;


public:

  void simplify(Mesh::MeshdataPtr agg_mesh, int32 numVerticesLeft);


};

}
}

==> sirikata-0.0.21-pre1-mac.tar.gz: sirikata_mac/include/sirikata/mesh/MeshSimplifier.hpp <==
/*  Sirikata
 *  MeshSimplifier.hpp
 *
 *  Copyright (c) 2010, Tahir Azim.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sirikata/mesh/Platform.hpp>
#include <sirikata/core/util/UUID.hpp>

#include <sirikata/core/transfer/TransferData.hpp>
#include <sirikata/core/transfer/RemoteFileMetadata.hpp>
#include <sirikata/core/transfer/TransferPool.hpp>
#include <sirikata/core/transfer/TransferMediator.hpp>

#include <sirikata/mesh/Meshdata.hpp>

namespace Sirikata {
namespace Mesh {

class SIRIKATA_MESH_EXPORT MeshSimplifier {
private:

  double invert(Matrix4x4f& inv, const Matrix4x4f& orig);

  typedef struct QSlimStruct {
    double mCost;
    int mGeomIdx, mIdx1, mIdx2;


    Vector3f mReplacementVector;

    QSlimStruct() {
      mCost = 1e-15;
    }

    QSlimStruct(float cost, int i, int idx1, int idx2, Vector3f v) {
      mCost = cost;
      mGeomIdx = i;
      mIdx1 = idx1;
      mIdx2 = idx2;
      mReplacementVector = v;
    }

    bool operator < (const QSlimStruct& qs) const {
      return mCost > qs.mCost;
    }

  } QSlimStruct;


public:

  void simplify(Mesh::MeshdataPtr agg_mesh, int32 numFacesLeft);


};

}
}
